@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/parser.c,v 1.8 2006/01/09 16:30:20 richb Exp $
+/*  $Header$
  *
- *  Copyright (C) 2004-2006 Sami Pietila
+ *  Copyright (C) 2004-2007 Sami Pietila
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -86,8 +86,7 @@ check_numbase(char *num)
 	    }
 	    break;
 	default:
-	    assert(0); // unknown base
+	    assert(0);      /* unknown base. */
 	}
     }
-    
 }
